function LoadingButton(el, options){
  this.el = el;
  this.options = options;
  this.init();
}

LoadingButton.prototype = {
  // Initialize everything
  init: function(){
    this.infinite = true;
    this.succeed = false;
    this.initDOM();
    this.initSegments();
    this.initEvents();
  },

  // Create an span element with inner text of the button and insert the corresponding SVG beside it
  initDOM: function(){
    this.el.innerHTML = '<span>' + this.el.innerHTML + '</span>';
    this.span = this.el.querySelector('span');
    var div = document.createElement('div');
    div.innerHTML = document.querySelector(this.options.svg).innerHTML;
    this.svg = div.querySelector('svg');
    this.el.appendChild(this.svg);
  },

  // Initialize the segments for all the paths of the loader itself, and for the success and error animations
  initSegments: function(){
    for(var i = 0, paths = this.options.paths, len = paths.length; i < len; i++){
      paths[i].el = this.svg.querySelector(paths[i].selector);
      paths[i].begin = paths[i].begin ? paths[i].begin : 0;
      paths[i].end = paths[i].end ? paths[i].end : 0.1;
      paths[i].segment = new Segment(paths[i].el, paths[i].begin, paths[i].end);
    }
  },

  // Initialize the click event in loading buttons, that trigger the animation
  initEvents: function(){
    var self = this;
      self.el.disabled = 'disabled';
      for(var i = 0, paths = self.options.paths, len = paths.length; i < len; i++){
        paths[i].animation.call(self, paths[i].segment);
      }
  },

  // Make it fail
  triggerFail: function(){
    this.infinite = false;
    this.succeed = false;
  },

  // Make it succeed
  triggerSuccess: function(){
    this.infinite = false;
    this.succeed = true;
  },

  // When each animation cycle is completed, check whether any feedback has triggered and call the feedback
  // handler, otherwise it restarts again
  completed: function(reset){
    if(this.infinite){
      for(var i = 0, paths = this.options.paths, len = paths.length; i < len; i++){
        if(reset){
          paths[i].segment.draw(0, 0.1);
        }
        paths[i].animation.call(this, paths[i].segment);
      }
    }else{

    }
  },

  // Reset the entire loading button to the initial state
  reset: function(){
    this.el.removeAttribute('disabled');
    this.resetSegments();
    this.infinite = true;
    for(var i = 0, paths = this.options.paths, len = paths.length; i < len; i++){
      paths[i].el.style.visibility = 'visible';
    }
  },

  // Reset the segments to the initial state
  resetSegments: function(){
    for(var i = 0, paths = this.options.paths, len = paths.length; i < len; i++){
      paths[i].segment.draw(paths[i].begin, paths[i].end);
    };
  }
};