define(function(require, exports, module) {

  var controller = require("./controller.js");
  var path = controller.path;
  var file = controller.file;
  var config = require("../config.js");

  exports.loadJsFile = function(jstype, callback) {

    var file1 = "./" + file + "." + jstype + ".js";
    var file2 = "";

    if(config && config.qsid) {
      file2 = "../../works" + config.qsid + "/" + path + "/" + file + "." + jstype + ".js";
    }

    seajs.use([file1, file2], function(conf, conf2) {
      
      if(!conf && !conf2) {
        alert("读取配置文件失败");
        return;
      }

      if(conf2) {
        conf = conf2;
      }

      callback(conf);

    })

  }

  /*
    dt: date 对象
    sp: 间隔标识，默认 ""
  */
  exports.fmtDate = function(dt, sp) {

    var y = dt.getFullYear();
    var m = dt.getMonth() + 1;
    var d = dt.getDate();

    if(m < 10) m = "0" + m;
    if(d < 10) d = "0" + d;

    sp = sp || "";
    return y + sp + m + sp + d;
  }

  /*
    dt: date 对象
    tt: 跨度值，如7，-7  7向后推移7
    type: 跨度单位，d,m,y  日，月，年
    sp: 间隔标识，默认 ""
  */
  exports.spanDate = function(dt, tt, type) {

    tt = tt || 0;
    type = type || "d";

    var nd;
    if(tt == 0) {
      return dt;
    }

    switch(type) {
      case "d":
        return new Date(dt.getFullYear(), dt.getMonth(), dt.getDate() + tt);
      case "m":
        return new Date(dt.getFullYear(), dt.getMonth() + tt, dt.getDate());
      case "y":
        return new Date(dt.getFullYear() + tt, dt.getMonth(), dt.getDate());
    }

    return dt;

  }

  /*
    获取请求入参信息，或者格式化请求入参信息

    fields: 入参的变量字段
    params: 入参中恒定变量字段
    row: 行记录数据

  */
  exports.getReqParams = function(fields, params, row) {

    var rt = {};

    if(fields && row) {

      fields.map(function(field) {

        // 对 field[1] 进行分割，支持2层key
        var ks = field[1].split(".");
        var v;
        if(ks.length == 1) {
          v = row[ks[0]];
        } 
        else if(ks.length == 2) {
          v = row[ks[0]][ks[1]];
        }

        if(field[0].toLowerCase() == "select") {
          rt["F123"] = v.gddm;
          rt["F125"] = v.sc;
        }
        else {
          rt[field[0]] = v;
        }
      })
    }

    $.extend(rt, params, {
      tdxPageID: "_UrlEncode"
    });

    return rt;
  }

  /*
    直接调用田工接口获取账户信息，本地调用
  */
  exports.__localCallTql = function(entry, param, callback) {

    var request = {};
    request.FuncName = "";
    request.Param = param;

    switch(entry) {
      case "local.SYS_FUNCUserInfo":
        request.Method = "SYS_FUNCUserInfo";
        break;
      case "local.Query_JyInfo":
        request.Method = "Query_JyInfo";
        break;
      default:
        break;
    }

    window.TDXQuery({
      request: JSON.stringify(request),
      onSuccess: function (response) {
        callback(response);
      },
      onFailure: function (errCode, errInfo) {
        // console.log('onFailure:'+errInfo);
        alert(errInfo);
      }
    });
  }

  /*
    自定义 alert 函数
  */
  exports.tdxAlert = function(params) {
    params.type = "alert";
    bus.$emit("tdx-dialog-show", params);
  }

  /*
    自定义 confirm 函数
  */
  exports.tdxConfirm = function(params) {
    params.type = "confirm";
    bus.$emit("tdx-dialog-show", params);
  }

  /*
    渲染出 form 类型的 html 字符串

    st: 配置信息

      [
        {
          input: 1,
          label: "客户姓名",
          field: "khxm",
          star1: 1
        },
        {
          input2: 1,
          label1: "客户姓名",
          field1: "khxm",
          star1: 1,
          label2: "性别",
          field2: "xb",
          star2: 1
        },
        {
          span: 1,
          text: ""
        }
      ]

    data: 数据
  */
  exports.renderStr = function(st, data) {

    var str = '<form class="tdx-form-all">';
    
    st.map(function(ss, index) {

      str += '<div class="tdx-form-line">';

      // 双列 input
      if(ss.input2 == 1) {

        str += '<span class="tdx-item-col-left">' + ss.label1 + ':</span>';
        str += '<input class="tdx-item-col-input" disabled="disabled" value="' + data[ss.field1] + '">';

        if(ss.star1 == 1) {
          str += '<span style="color:red;">*</span>';
        }

        str += '<span class="tdx-item-col-left">' + ss.label2 + ':</span>';
        str += '<input class="tdx-item-col-input" disabled="disabled" value="' + data[ss.field2] + '">';

        if(ss.star2 == 1) {
          str += '<span style="color:red;">*</span>';
        }
      }

      // 单列 input
      else if(ss.input == 1) {

        str += '<span class="tdx-item-col-left">' + ss.label + ":</span>";
        str += '<input class="tdx-item-col-input" disabled="disabled" value="' + data[ss.field] + '">';
        if(ss.star == 1) {
          str += '<span style="color:red;">*</span>';
        }
      }

      // 提示信息
      else if(ss.span == 1) {

        str += '<span class="tdx-item-col-span">' + ss.text + '</span>';
      }

      str += '</div>';

    });

    str += '</form>';

    return str;

  }

  /*
    这里多层 field，获取对应的 value

    例如：
    
    field 配置："Content.Data.lpszDefTxt"

    那么返回的 value 是

    value = rowdata["Content"]["Data"]["lpszDefTxt"]
  */
  exports.getValueByFields = function(rowdata, fields) {

    var tmpValue;

    var fieldsArr = fields.split(".");

    fieldsArr.map(function(field) {
      if(tmpValue) {
        tmpValue = tmpValue[field];
      }
      else {
        tmpValue = rowdata[field];
      }
    })

    return tmpValue;
  }
})